const config = require(".");
const reportCodeCoverage = require("browserify-istanbul");

const jsFiles = `${config.sourceDirectory}/javascripts/*.js`;
const jsTestFiles = `${config.sourceDirectory}/javascripts/__tests__/*.js`;
const coverageDir = `${config.testReportDirectory}/coverage`;

const karmaConfig = {
    frameworks: ["mocha", "sinon-chai", "browserify"],
    files: [jsFiles, jsTestFiles],
    preprocessors: {
        [jsFiles]: ["browserify"],
        [jsTestFiles]: ["browserify"],
    },
    reporters: ["spec", "html", "coverage"],
    plugins: [
        "karma-teamcity-reporter",
        "karma-coverage",
        "karma-mocha",
        "karma-browserify",
        "karma-html-reporter",
        "karma-spec-reporter",
        "karma-chrome-launcher",
        "karma-sinon-chai",
    ],
    browsers: ["ChromeHeadless"],

    browserify: {
        debug: true,
        transform: [
            ["babelify", {
                ignore: ["**/node_modules/**"],
            }],
            reportCodeCoverage({
                instrumenterConfig: {
                    embedSource: true,
                },
                ignore: ["**/__tests__/**", "**/node_modules/**"],
            }),
        ],
    },

    htmlReporter: {
        outputDir: config.testReportDirectory,
    },
    coverageReporter: {
        dir: coverageDir,
        reporters: [
            { type: "text" },
            { type: "html" },
        ],
    },
};

module.exports = karmaConfig;
