const gulp = require("gulp");
const sourcemaps = require("gulp-sourcemaps");
const source = require("vinyl-source-stream");
const buffer = require("vinyl-buffer");
const browserify = require("browserify");
const watchify = require("watchify");
const babel = require("babelify");
const merge = require("merge");
const handleErrors = require("../lib/handleErrors");
const config = require("../config/browserify");

gulp.task("browserify:development", (cb) => {
    let notified = false;
    let bundler = browserify(config.entryPoint, merge({ debug: true }, config.options))
        .transform(babel.configure(config.babel));
    if (global.watch) {
        bundler = watchify(bundler);
    }

    function rebundle() {
        bundler.bundle()
            .on("error", handleErrors)
            .pipe(source("sdk.js"))
            .pipe(buffer())
            .pipe(sourcemaps.init({ loadMaps: true }))
            .pipe(sourcemaps.write("./"))
            .pipe(gulp.dest(config.output))
            .on("end", () => {
                if (!notified) {
                    notified = true;
                    cb();
                }
            });
    }

    if (global.watch) {
        bundler.on("update", () => {
            rebundle();
        });
    }

    rebundle();
});
