import PolyFill from "./PolyFill";
import HyperwalletConfiguration from "./HyperwalletConfiguration";
import HyperwalletTransaction from "./HyperwalletTransaction";
import Hyperwallet from "./Hyperwallet";

export default {

    HyperwalletTransaction,
    Hyperwallet,

    translate(key, isNullable = false) {
        if (this.translation[key]) {
            return this.translation[key];
        }
        return (isNullable) ? undefined : `${key} no translation`;
    },

    initTranslation(translation, locale) {
        this.translation = translation;
        this.locale = locale;
    },

    initialize(retrieveAuthenticationToken) {
        PolyFill.init();
        HyperwalletTransaction.init(this.locale);
        this.hyperwalletConfiguration = new HyperwalletConfiguration(retrieveAuthenticationToken);
    },

    isAuthenticated() {
        return this.hyperwalletConfiguration !== undefined && this.hyperwalletConfiguration.isSetup();
    },

    getHyperwalletConfiguration(callback) {
        this.hyperwalletConfiguration.getAuthenticationToken((authenticationToken, error) => {
            if (error) {
                callback(error);
            }
            callback(null, this.hyperwalletConfiguration);
        });
    },

    initializePartner(partnerConfig = []) {
        this.partners = partnerConfig;
    },

    getPartnerConfiguration(partnerType) {
        return this.partners.find(({ partner }) => partner === partnerType);
    },
};
